summaryrefslogtreecommitdiff
path: root/src/item.go
diff options
context:
space:
mode:
authorJunegunn Choi <junegunn.c@gmail.com>2025-01-13 17:37:50 +0900
committerJunegunn Choi <junegunn.c@gmail.com>2025-01-13 17:37:50 +0900
commit56fef7c8df2713261fbdbd396aa81ed23d9a945a (patch)
treeb8f8c52f84f7c4a37cca062dcc871e91fc63f160 /src/item.go
parentba0935c71f5507958056201ddad2fc48674a586d (diff)
downloadfzf-56fef7c8df2713261fbdbd396aa81ed23d9a945a.tar.gz
Simplify nth comparison when reusing transformed tokens
Diffstat (limited to 'src/item.go')
-rw-r--r--src/item.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/item.go b/src/item.go
index 6b91d069..1943486f 100644
--- a/src/item.go
+++ b/src/item.go
@@ -8,9 +8,9 @@ import (
type transformed struct {
// Because nth can be changed dynamically by change-nth action, we need to
- // keep the nth value at the time of transformation.
- nth []Range
- tokens []Token
+ // keep the revision number at the time of transformation.
+ revision int
+ tokens []Token
}
// Item represents each input line. 56 bytes.